@@ -149,12 +149,24 @@ class rdesktop:
 		self.toolbar = self.wTree.get_widget("toolbar")
 		self.mainMenu = self.wTree.get_widget("menu_main")
 
-		#Advanced Preferences Dialog
+		#Advanced Preferences Dialog -- Advanced Tab
 		self.pref_console = self.wTree.get_widget("pref_console")
 		self.dlg_advanced = self.wTree.get_widget("dlg_advanced")
 		self.pref_compression = self.wTree.get_widget("pref_compression")
 		self.pref_bitmap = self.wTree.get_widget("pref_bitmap")
 		self.pref_encryption = self.wTree.get_widget("pref_encryption")
+                
+                #Advanced Preferences Dialog -- Experience Tab
+                self.cmb_exp_preset = self.wTree.get_widget("cmb_exp_preset")
+                self.chk_exp_desktop = self.wTree.get_widget("chk_exp_desktop")
+                self.chk_exp_font = self.wTree.get_widget("chk_exp_font")
+                self.chk_exp_composition = self.wTree.get_widget("chk_exp_composition")
+                self.chk_exp_drag = self.wTree.get_widget("chk_exp_drag")
+                self.chk_exp_animation = self.wTree.get_widget("chk_exp_animation")
+                self.chk_exp_themes = self.wTree.get_widget("chk_exp_themes")
+                self.chk_exp_bitmap = self.wTree.get_widget("chk_exp_bitmap")
+                
+                #Advanced Preferences Dialog -- General
 		self.pref_cancel = self.wTree.get_widget("pref_cancel")
 		self.pref_save = self.wTree.get_widget("pref_save")
 
@@ -187,6 +199,7 @@ class rdesktop:
 		#Make sure these have the first value selected (not no value)		
 		self.colordepth.set_active(0)
 		self.sound.set_active(0)
+                self.cmb_exp_preset.set_active(0)
 
 		#Hooray hildon! :-P  Don't autocapitalize host, username, password, and don't predict for password
 		self.host.set_property('hildon-input-mode', (1 << 0 | 1 << 1 | 1 << 2))
@@ -226,7 +239,8 @@ class rdesktop:
 			"show_extra" : self.show_extra,
 			"show_about" : self.show_about,
 			"save_advanced" : self.ok_advanced,
-			"cancel_advanced" : self.cancel_advanced}
+			"cancel_advanced" : self.cancel_advanced,
+                        "exp_preset_change" : self.exp_preset_change}
 		self.wTree.signal_autoconnect(dic)
 
 	def ErrPopUp(self,msg):
@@ -238,23 +252,69 @@ class rdesktop:
 		# error_dialog.connect("delete-event", delete_event, self)
 		self.error_dialog = error_dialog
 		error_dialog.run()
+        
+        def reset_exp_checks(self) :
+                self.chk_exp_desktop.set_active(False)
+                self.chk_exp_font.set_active(False)
+                self.chk_exp_composition.set_active(False)
+                self.chk_exp_drag.set_active(False)
+                self.chk_exp_animation.set_active(False)
+                self.chk_exp_themes.set_active(False)
+                self.chk_exp_bitmap.set_active(False)
+        
+        def exp_preset_change(self, widget) : #If we change the presets, update the checkboxes
+                #I was smart when writing this function, to avoid rewriting code
+                #The presets just add on themselves going up...
+                self.reset_exp_checks()
+                if self.cmb_exp_preset.get_active() >= 0 :
+                        self.chk_exp_bitmap.set_active(True)
+                if self.cmb_exp_preset.get_active() >= 1 :
+                        self.chk_exp_themes.set_active(True)
+                if self.cmb_exp_preset.get_active() >= 2 :
+                        self.chk_exp_animation.set_active(True)
+                        self.chk_exp_drag.set_active(True)
+                        self.chk_exp_composition.set_active(True)
+                if self.cmb_exp_preset.get_active() >= 3 :
+                        self.chk_exp_font.set_active(True)
+                        self.chk_exp_desktop.set_active(True)
+                if self.cmb_exp_preset.get_active() == 4 :
+                        self.reset_exp_checks()
 
 	def ok_advanced(self, widget) :
 		self.dlg_advanced.hide()
 
 	def cancel_advanced(self, widget) :
-		#self.pref_console.set_active(self._tempconsole)
+                #Reset the Advanced Tab
+		self.pref_console.set_active(self._tempconsole)
 		self.pref_compression.set_active(self._tempcompress)
 		self.pref_bitmap.set_active(self._tempbitmap)
 		self.pref_encryption.set_active(self._tempencryption)
+                #Reset the experience tab
+                self.cmb_exp_preset.set_active(self._tempexp_preset)
+                self.chk_exp_desktop.set_active(self._tempexp_desktop)
+                self.chk_exp_font.set_active(self._tempexp_font)
+                self.chk_exp_composition.set_active(self._tempexp_composition)
+                self.chk_exp_drag.set_active(self._tempexp_drag)
+                self.chk_exp_animation.set_active(self._tempexp_animation)
+                self.chk_exp_themes.set_active(self._tempexp_themes)
+                self.chk_exp_bitmap.set_active(self._tempexp_bitmap)
 		self.dlg_advanced.hide()
 
 	def show_extra(self,widget):
 		#self.dlg_advanced.show()
-		#self._tempconsole = self.pref_console.get_active()
+		self._tempconsole = self.pref_console.get_active()
 		self._tempcompress = self.pref_compression.get_active()
 		self._tempbitmap = self.pref_bitmap.get_active()
 		self._tempencryption = self.pref_encryption.get_active()
+                #Temporary variables for experience tab
+                self._tempexp_preset = self.cmb_exp_preset.get_active()
+                self._tempexp_desktop = self.chk_exp_desktop.get_active()
+                self._tempexp_font = self.chk_exp_font.get_active()
+                self._tempexp_composition = self.chk_exp_composition.get_active()
+                self._tempexp_drag = self.chk_exp_drag.get_active()
+                self._tempexp_animation = self.chk_exp_animation.get_active()
+                self._tempexp_themes = self.chk_exp_themes.get_active()
+                self._tempexp_bitmap = self.chk_exp_bitmap.get_active()
 		result = self.dlg_advanced.run()
 		if result == 1 :
 			self.ok_advanced("")
@@ -364,6 +424,24 @@ class rdesktop:
 		#Console mode? -- I wasn't sure how this worked, but appearently it's required sometimes...
 		if self.pref_console.get_active() == True :
 			to_run = to_run + " -0"
+                        
+                #TODO: RDP Experience Falgs! -x
+                #Check for Presets first... we can have those pre-defined
+                tempexp = 0x00
+                if self.chk_exp_desktop.get_active() == False :
+                        tempexp = tempexp | 0x01
+                if self.chk_exp_font.get_active() == False :
+                        tempexp = tempexp | 0x80
+                if self.chk_exp_composition.get_active() == False :
+                        tempexp = tempexp | 0x20
+                if self.chk_exp_drag.get_active() == False :
+                        tempexp = tempexp | 0x02
+                if self.chk_exp_animation.get_active() == False :
+                        tempexp = tempexp | 0x04
+                if self.chk_exp_themes.get_active() == False :
+                        tempexp = tempexp | 0x08
+                if self.chk_exp_bitmap.get_active() == False :
+                        tempexp = tempexp | 0x40
 
 		#Now run it! -- I'd like to be able to keep the GUI open, but I need to figure out threading, first...
 		#self.window.hide()
@@ -394,6 +472,14 @@ class rdesktop:
 		self.client.set_bool("/apps/rdesktop/"+prof+"/compression", self.pref_compression.get_active())
 		self.client.set_bool("/apps/rdesktop/"+prof+"/bitmap", self.pref_bitmap.get_active())
 		self.client.set_bool("/apps/rdesktop/"+prof+"/encryption", self.pref_encryption.get_active())
+                self.client.set_int("/apps/rdesktop/"+prof+"/exp_preset", self.cmb_exp_preset.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_desktop", self.chk_exp_desktop.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_font", self.chk_exp_font.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_composition", self.chk_exp_composition.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_drag", self.chk_exp_drag.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_animation", self.chk_exp_animation.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_themes", self.chk_exp_themes.get_active())
+                self.client.set_bool("/apps/rdesktop/"+prof+"/exp_bitmap", self.chk_exp_bitmap.get_active())
 
 	def new_profile(self,widget) :
 		#This is just a placeholder - Not anymore!
@@ -412,6 +498,14 @@ class rdesktop:
 		self.pref_compression.set_active(True)
 		self.pref_bitmap.set_active(True)
 		self.pref_encryption.set_active(True)
+                self.cmb_exp_preset.set_active(0)
+                self.chk_exp_desktop.set_active(False)
+                self.chk_exp_font.set_active(False)
+                self.chk_exp_composition.set_active(False)
+                self.chk_exp_drag.set_active(False)
+                self.chk_exp_animation.set_active(False)
+                self.chk_exp_themes.set_active(False)
+                self.chk_exp_bitmap.set_active(True)
 
 	def delete_profile(self, widget) :
 		#This is just a placeholder
@@ -451,6 +545,14 @@ class rdesktop:
 		self.pref_compression.set_active(self.client.get_bool(profile + "/compression"))
 		self.pref_bitmap.set_active(self.client.get_bool(profile + "/bitmap"))
 		self.pref_encryption.set_active(self.client.get_bool(profile + "/encryption"))
+                self.cmb_exp_preset.set_active(self.client.get_int(profile + "/exp_preset"))
+                self.chk_exp_desktop.set_active(self.client.get_bool(profile + "/exp_desktop"))
+                self.chk_exp_font.set_active(self.client.get_bool(profile + "/exp_font"))
+                self.chk_exp_composition.set_active(self.client.get_bool(profile + "/exp_composition"))
+                self.chk_exp_drag.set_active(self.client.get_bool(profile + "/exp_drag"))
+                self.chk_exp_animation.set_active(self.client.get_bool(profile + "/exp_animation"))
+                self.chk_exp_themes.set_active(self.client.get_bool(profile + "/exp_themes"))
+                self.chk_exp_bitmap.set_active(self.client.get_bool(profile + "/exp_bitmap"))
 		p = re.compile("\d+")
 		num = p.findall(profile)[0]
 		#self.ErrPopUp("selected prof"+num)
